psychopy_ext.stats.nan_outliers — psychopy_ext 0.5.4 documentation
Author: Jonas Kubilius
Description: A framework for a rapid reproducible design, analysis and plotting of experiments in neuroscience and psychology

# psychopy_ext.stats.nan_outliers

`psychopy_ext.stats.` `nan_outliers`(df, values=None, group=None)

  Remove outliers 3 standard deviations away from the mean

  Args:
    df (pandas.DataFrame): A DataFrame with your data
  Kwargs:
    values (str): Name of the column that needs to have outliers removed group (str): Name of the column to group reponses by. Typically, this is the column with subject IDs, so that you remove outliers for each participant separately (based on their mean and std)
  Returns:
    df (pandas.DataFrame): A DataFrame without outliers